@@ -18,7 +18,7 @@ from six.moves.urllib.parse import quote
 
 from marquez_client import errors
 from marquez_client.constants import (DEFAULT_TIMEOUT_MS)
-from marquez_client.models import DatasetType, SourceType, JobType
+from marquez_client.models import (DatasetType, JobType)
 from marquez_client.utils import Utils
 from marquez_client.version import VERSION
 
@@ -75,12 +75,11 @@ class MarquezClient(object):
     def create_source(self, source_name, source_type, connection_url,
                       description=None):
         Utils.check_name_length(source_name, 'source_name')
-        Utils.is_instance_of(source_type, SourceType)
 
         Utils.is_valid_connection_url(connection_url)
 
         payload = {
-            'type': source_type.value,
+            'type': source_type,
             'connectionUrl': connection_url
         }
 
