@@ -29,7 +29,7 @@ class FileBackend(Backend):
         os.makedirs(path, exist_ok=True)
         return file
 
-    def put(self, path, headers, json):
+    def put(self, path, headers, json_payload):
         log.debug("_put()")
 
         put_details = {}
@@ -37,13 +37,14 @@ class FileBackend(Backend):
         put_details['method'] = 'PUT'
         put_details['path'] = path
         put_details['headers'] = headers
-        put_details['payload'] = json
+        put_details['payload'] = json_payload
 
-        log.info(put_details)
+        put_json = json.dumps(put_details)
+        log.info(put_json)
 
-        self._sync_file(put_details)
+        self._sync_file(put_json)
 
-    def post(self, path, headers, json=None):
+    def post(self, path, headers, json_payload=None):
         log.debug("_post()")
 
         post_details = {}
@@ -51,14 +52,16 @@ class FileBackend(Backend):
         post_details['method'] = 'POST'
         post_details['path'] = path
         post_details['headers'] = headers
-        post_details['payload'] = json
+        if json_payload:
+            post_details['payload'] = json_payload
 
-        log.info(post_details)
+        post_json = json.dumps(post_details)
+        log.info(post_json)
 
-        self._sync_file(post_details)
+        self._sync_file(post_json)
 
     def _sync_file(self, json_data):
-        self._file.write(json.dumps(json_data))
+        self._file.write(json_data)
         self._file.write(os.linesep)
         self._file.flush()
         os.fsync(self._file.fileno())
